from allensdk.model.biophys_sim.config import Config
from allensdk.model.biophys_sim.neuron.hoc_utils import HocUtils


class Utils(HocUtils):
    def __init__(self, description=None):
        description = Config().load('manifest.json')
        super(Utils, self).__init__(description)
        self.generate_cell()

    def generate_cell(self):
        # cell = self.h.cell()
        from neuron import h as H
        H.load_file("cell_template.hoc")
        cell = H.cell()
        morphology_path = self.description.manifest.get_path('MORPHOLOGY')
        self.generate_morphology(cell, morphology_path)
        self.load_cell_parameters(cell)
        self.cell = cell

    def generate_morphology(self, cell, morph_filename):
        h = self.h

        swc = self.h.Import3d_SWC_read()
        swc.input(morph_filename)
        imprt = self.h.Import3d_GUI(swc, 0)
        imprt.instantiate(cell)

        for seg in cell.soma[0]:
            seg.area()

        for sec in cell.all:
            sec.nseg = 1 + 2 * int(sec.L / 40)

        cell.simplify_axon()
        for sec in cell.axonal:
            sec.L = 30
            sec.diam = 1
            sec.nseg = 1 + 2 * int(sec.L / 40)
        cell.axon[0].connect(cell.soma[0], 0.5, 0)
        cell.axon[1].connect(cell.axon[0], 1, 0)
        h.define_shape()

    def load_cell_parameters(self, cell):
        passive = self.description.data['passive'][0]
        conditions = self.description.data['conditions'][0]
        genome = self.description.data['genome']

        # Set passive properties
        # cm_dict = dict([(c['section'], c['cm']) for c in passive['cm']])
        for sec in cell.all:
        # 	sec.Ra = passive['ra']
        # 	sec.cm = cm_dict[sec.name().split(".")[1][:4]]
            sec.insert('pas')
        # 	for seg in sec:
        # 		seg.pas.e = passive["e_pas"]

        # Insert channels and set parameters
        for p in genome:
            sections = [s for s in cell.all if s.name().split(".")[1][:4] == p["section"]]
            for sec in sections:
                if p["mechanism"] != "":
                    sec.insert(p["mechanism"])
                else:
                    if p["name"] == 'Ra':
                        sec.Ra = float(p["value"])
                    elif p["name"] == "cm":
                        sec.cm = float(p["value"])
                    elif p["name"] == "g_pas":
                        for seg in sec:
                            seg.pas.g = float(p["value"])
                    elif p["name"] == "e_pas":
                        for seg in sec:
                            seg.pas.e = float(p["value"])
                    else:
                        for seg in sec:
                            seg.pas.g =float(p["value"])
                setattr(sec, p["name"], float(p["value"]))

        # Set reversal potentials
        for erev in conditions['erev']:
            sections = [s for s in cell.all if s.name().split(".")[1][:4] == erev["section"]]
            for sec in sections:
                sec.ena = erev["ena"]
                sec.ek = erev["ek"]
